@@ -65,10 +65,10 @@ make_binary_release() {
   echo "Creating ${HADOOP_VERSION} binary release"
 
   # enable release profile here (to check for the maven version)
-  $MVN clean package ${HADOOP_PROFILE} -P no-extended-disk-storage,no-option-dependency,no-plugin-bin -pl ':dist' -am -Dgpg.skip -Dcheckstyle.skip=true -DskipTests
+  $MVN clean package ${HADOOP_PROFILE} -Pno-extended-disk-storage -Pfail-on-no-git-dir -Pno-plugin-bin -pl ':dist' -am -Dgpg.skip -Dcheckstyle.skip=true -DskipTests
 
   local TARGET_FILE="apache-amoro-${RELEASE_VERSION}-bin-${HADOOP_VERSION}.tar.gz"
-  cp amoro-ams/dist/target/apache-amoro-${RELEASE_VERSION}-bin.tar.gz ${RELEASE_DIR}/${TARGET_FILE}
+  cp dist/target/apache-amoro-${RELEASE_VERSION}-bin.tar.gz ${RELEASE_DIR}/${TARGET_FILE}
   cd ${RELEASE_DIR}
 
   # Sign sha the tgz
